package SPVM::Compress::Raw::Zlib::Constant;



1;

=encoding utf8

=head1 Name

SPVM::Compress::Raw::Zlib::Constant - zlib Constants

=head1 Description

Compress::Raw::Zlib::Constant class in L<SPVM> has methods to get L<zlib|https://en.wikipedia.org/wiki/Zlib> constants.

=head1 Usage

  use Compress::Raw::Zlib::Constant as ZLIB;
  
=head1 Class Methods

=head2 DEF_WBITS

C<static method DEF_WBITS : int ();>

Returns the value of C<DEF_WBITS>. If this constant is not defined on the system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 MAX_MEM_LEVEL

C<static method MAX_MEM_LEVEL : int ();>

Returns the value of C<MAX_MEM_LEVEL>. If this constant is not defined on the system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 MAX_WBITS

C<static method MAX_WBITS : int ();>

Returns the value of C<MAX_WBITS>. If this constant is not defined on the system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 OS_CODE

C<static method OS_CODE : int ();>

Returns the value of C<OS_CODE>. If this constant is not defined on the system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 Z_ASCII

C<static method Z_ASCII : int ();>

Returns the value of C<Z_ASCII>. If this constant is not defined on the system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 Z_BEST_COMPRESSION

C<static method Z_BEST_COMPRESSION : int ();>

Returns the value of C<Z_BEST_COMPRESSION>. If this constant is not defined on the system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 Z_BEST_SPEED

C<static method Z_BEST_SPEED : int ();>

Returns the value of C<Z_BEST_SPEED>. If this constant is not defined on the system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 Z_BINARY

C<static method Z_BINARY : int ();>

Returns the value of C<Z_BINARY>. If this constant is not defined on the system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 Z_BLOCK

C<static method Z_BLOCK : int ();>

Returns the value of C<Z_BLOCK>. If this constant is not defined on the system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 Z_BUF_ERROR

C<static method Z_BUF_ERROR : int ();>

Returns the value of C<Z_BUF_ERROR>. If this constant is not defined on the system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 Z_DATA_ERROR

C<static method Z_DATA_ERROR : int ();>

Returns the value of C<Z_DATA_ERROR>. If this constant is not defined on the system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 Z_DEFAULT_COMPRESSION

C<static method Z_DEFAULT_COMPRESSION : int ();>

Returns the value of C<Z_DEFAULT_COMPRESSION>. If this constant is not defined on the system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 Z_DEFAULT_STRATEGY

C<static method Z_DEFAULT_STRATEGY : int ();>

Returns the value of C<Z_DEFAULT_STRATEGY>. If this constant is not defined on the system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 Z_DEFLATED

C<static method Z_DEFLATED : int ();>

Returns the value of C<Z_DEFLATED>. If this constant is not defined on the system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 Z_ERRNO

C<static method Z_ERRNO : int ();>

Returns the value of C<Z_ERRNO>. If this constant is not defined on the system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 Z_FILTERED

C<static method Z_FILTERED : int ();>

Returns the value of C<Z_FILTERED>. If this constant is not defined on the system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 Z_FINISH

C<static method Z_FINISH : int ();>

Returns the value of C<Z_FINISH>. If this constant is not defined on the system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 Z_FIXED

C<static method Z_FIXED : int ();>

Returns the value of C<Z_FIXED>. If this constant is not defined on the system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 Z_FULL_FLUSH

C<static method Z_FULL_FLUSH : int ();>

Returns the value of C<Z_FULL_FLUSH>. If this constant is not defined on the system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 Z_HUFFMAN_ONLY

C<static method Z_HUFFMAN_ONLY : int ();>

Returns the value of C<Z_HUFFMAN_ONLY>. If this constant is not defined on the system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 Z_MEM_ERROR

C<static method Z_MEM_ERROR : int ();>

Returns the value of C<Z_MEM_ERROR>. If this constant is not defined on the system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 Z_NEED_DICT

C<static method Z_NEED_DICT : int ();>

Returns the value of C<Z_NEED_DICT>. If this constant is not defined on the system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 Z_NO_COMPRESSION

C<static method Z_NO_COMPRESSION : int ();>

Returns the value of C<Z_NO_COMPRESSION>. If this constant is not defined on the system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 Z_NO_FLUSH

C<static method Z_NO_FLUSH : int ();>

Returns the value of C<Z_NO_FLUSH>. If this constant is not defined on the system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 Z_OK

C<static method Z_OK : int ();>

Returns the value of C<Z_OK>. If this constant is not defined on the system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 Z_PARTIAL_FLUSH

C<static method Z_PARTIAL_FLUSH : int ();>

Returns the value of C<Z_PARTIAL_FLUSH>. If this constant is not defined on the system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 Z_RLE

C<static method Z_RLE : int ();>

Returns the value of C<Z_RLE>. If this constant is not defined on the system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 Z_STREAM_END

C<static method Z_STREAM_END : int ();>

Returns the value of C<Z_STREAM_END>. If this constant is not defined on the system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 Z_STREAM_ERROR

C<static method Z_STREAM_ERROR : int ();>

Returns the value of C<Z_STREAM_ERROR>. If this constant is not defined on the system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 Z_SYNC_FLUSH

C<static method Z_SYNC_FLUSH : int ();>

Returns the value of C<Z_SYNC_FLUSH>. If this constant is not defined on the system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 Z_UNKNOWN

C<static method Z_UNKNOWN : int ();>

Returns the value of C<Z_UNKNOWN>. If this constant is not defined on the system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 Z_VERSION_ERROR

C<static method Z_VERSION_ERROR : int ();>

Returns the value of C<Z_VERSION_ERROR>. If this constant is not defined on the system, an exception is thrown with the error id set to the basic type ID of the L<Error::NotSupported|SPVM::Error::NotSupported> class.

=head2 WANT_GZIP

C<static method WANT_GZIP : int ();>

Returns 16.

=head2 WANT_GZIP_OR_ZLIB

C<static method WANT_GZIP_OR_ZLIB : int ();>

Returns 32.

=head1 See Also

=over 2

=item * L<Compress::Raw::Zlib|SPVM::Compress::Raw::Zlib>

=back
